package com.gtunes

class User implements Serializable {

	private static final long serialVersionUID = 1

	transient springSecurityService

	String login
	String password
	boolean enabled = true
	boolean accountExpired
	boolean accountLocked
	boolean passwordExpired
        Date dateCreated
        Date lastUpdated

        String firstName
        String lastName

        static hasMany = [purchasedSongs:Song]

	User(String login, String password) {
		this()
		this.login = login
		this.password = password
	}

	@Override
	int hashCode() {
		login?.hashCode() ?: 0
	}

	@Override
	boolean equals(other) {
		is(other) || (other instanceof User && other.login == login)
	}

	@Override
	String toString() {
		login
	}

	Set<Role> getAuthorities() {
		UserRole.findAllByUser(this)*.role
	}

	def beforeInsert() {
		encodePassword()
	}

	def beforeUpdate() {
		if (isDirty('password')) {
			encodePassword()
		}
	}

	protected void encodePassword() {
		password = springSecurityService?.passwordEncoder ? springSecurityService.encodePassword(password) : password
	}

	static transients = ['springSecurityService']

	static constraints = {
		login blank: false, unique: true
		password blank: false
		firstName blank:false, nullable:false
		lastName blank:false, nullable:false
	}

	static mapping = {
		password column: '`password`'
	}
}
